
%global base_name   daemon
%global short_name  commons-%{base_name}

Name:           apache-%{short_name}
Version:        1.0.10
Release:        %mkrel 4
Summary:        Defines API to support an alternative invocation mechanism
License:        ASL 2.0
Group:          Development/Java
URL:            http://commons.apache.org/%{base_name}
Source0:        http://archive.apache.org/dist/commons/%{base_name}/source/%{short_name}-%{version}-src.tar.gz
Patch0:         0001-execve-path-warning.patch
Patch1:         apache-commons-daemon-JAVA_OS.patch
Patch2:         apache-commons-daemon-s390x.patch
BuildRequires:  java-devel >= 1:1.6.0
BuildRequires:  jpackage-utils
BuildRequires:  maven
BuildRequires:  apache-commons-parent
BuildRequires:  maven-surefire-provider-junit
BuildRequires:  xmlto
BuildRequires:  docbook-dtds
BuildRequires:  docbook-style-xsl

Requires:         java >= 1:1.6.0
Requires:         jpackage-utils


# This should go away with F-17
Provides:       jakarta-%{short_name} = 1:%{version}-%{release}
Obsoletes:      jakarta-%{short_name} <= 1:1.0.1


%description
The scope of this package is to define an API in line with the current
Java Platform APIs to support an alternative invocation mechanism
which could be used instead of the public static void main(String[])
method.  This specification covers the behavior and life cycle of what
we define as Java daemons, or, in other words, non interactive
Java applications.

%package        jsvc
Summary:        Java daemon launcher
Group:          Development/Java
Provides:       jsvc = 1:%{version}-%{release}

Provides:       jakarta-%{short_name}-jsvc = 1:%{version}-%{release}
Obsoletes:      jakarta-%{short_name}-jsvc <= 1:1.0.1

%description    jsvc
%{summary}.

%package        javadoc
Summary:        API documentation for %{name}
Group:          Development/Java
Requires:       jpackage-utils
BuildArch:      noarch

Obsoletes:      jakarta-%{short_name}-javadoc <= 1:1.0.1

%description    javadoc
%{summary}.


%prep
%setup -q -n %{short_name}-%{version}-src
%patch0 -p1 -b .execve
%patch1 -p1 -b .java_os
%patch2 -p1 -b .s390x

# remove java binaries from sources
rm -rf src/samples/build/

chmod 644 src/samples/*
cd src/native/unix
xmlto man man/jsvc.1.xml


%build

# build native jsvc
pushd src/native/unix
%configure --with-java=%{java_home}
# this is here because 1.0.2 archive contains old *.o
make clean
make %{?_smp_mflags}
popd

# build jars
mvn-rpmbuild install javadoc:javadoc



%install

# install native jsvc
install -Dpm 755 src/native/unix/jsvc $RPM_BUILD_ROOT%{_bindir}/jsvc
install -Dpm 644 src/native/unix/jsvc.1 $RPM_BUILD_ROOT%{_mandir}/man1/jsvc.1

# jars
install -Dpm 644 target/%{short_name}-%{version}.jar $RPM_BUILD_ROOT%{_javadir}/%{name}.jar
ln -sf %{name}.jar %{buildroot}%{_javadir}/%{short_name}.jar


# pom
install -Dpm 644 pom.xml $RPM_BUILD_ROOT%{_mavenpomdir}/JPP-%{name}.pom
%add_maven_depmap JPP-%{name}.pom %{name}.jar -a "org.apache.commons:%{short_name}"


# javadoc
install -d -m 755 $RPM_BUILD_ROOT%{_javadocdir}/%{name}
cp -pr target/site/apidocs/* $RPM_BUILD_ROOT%{_javadocdir}/%{name}

%pre javadoc
# workaround for rpm bug, can be removed in F-17
[ $1 -gt 1 ] && [ -L %{_javadocdir}/%{name} ] && \
rm -rf $(readlink -f %{_javadocdir}/%{name}) %{_javadocdir}/%{name} || :


%files
%doc LICENSE.txt PROPOSAL.html NOTICE.txt RELEASE-NOTES.txt src/samples
%doc src/docs/*
%{_javadir}/%{name}.jar
%{_javadir}/%{short_name}.jar
%{_mavenpomdir}/JPP-%{name}.pom
%{_mavendepmapfragdir}/%{name}


%files jsvc
%doc LICENSE.txt
%{_bindir}/jsvc
%{_mandir}/man1/jsvc.1*


%files javadoc
%doc %{_javadocdir}/%{name}
%doc LICENSE.txt




%changelog

* Fri Jan 11 2013 umeabot <umeabot> 1.0.10-4.mga3
+ Revision: 345690
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Sep 13 2012 dmorgan <dmorgan> 1.0.10-3.mga3
+ Revision: 293265
- add s390x as known arch

* Mon Jul 16 2012 dmorgan <dmorgan> 1.0.10-2.mga3
+ Revision: 271288
- $supported_os and $JAVA_OS in configure do not always match
- on arches that override supported_os to be the arch we can not find headers

* Mon Jul 09 2012 dmorgan <dmorgan> 1.0.10-1.mga3
+ Revision: 269043
- New version 1.0.10
- Update to latest upstream (1.0.8)
- Drop s390/ppc patches (upstream seems to already include them)

* Tue Sep 06 2011 tv <tv> 1.0.7-1.mga2
+ Revision: 139176
- new release

  + dmorgan <dmorgan>
    - Update to latest upstream (1.0.6)
    - Cleanups according to new guidelines

* Tue Jul 19 2011 dmorgan <dmorgan> 1.0.5-5.mga2
+ Revision: 126799
- Use mvn-rpmbuild instead of mvn-local (changes in maven)

* Wed Apr 27 2011 dmorgan <dmorgan> 1.0.5-4.mga1
+ Revision: 92229
- Rebuild after bootstrapping
- imported package apache-commons-daemon

